return <<'END';
002b	
003c	003e
007c	
007e	
00ac	
00b1	
00d7	
00f7	
2044	
207a	207c
208a	208c
2190	2194
219a	219b
21a0	
21a3	
21a6	
21ae	
21ce	21cf
21d2	
21d4	
2200	22f1
2308	230b
2320	2321
25b7	
25c1	
266f	
fb29	
fe62	
fe64	fe66
ff0b	
ff1c	ff1e
ff5c	
ff5e	
ffe2	
ffe9	ffec
END
